@@ -1,4 +1,4 @@
-/* Eye Of Gnome - GConf Keys Macros 
+/* Eye Of Gnome - GConf Keys Macros
  *
  * Copyright (C) 2000-2006 The Free Software Foundation
  *
@@ -40,8 +40,6 @@
 #define EOG_CONF_VIEW_TRANSPARENCY		"/apps/eog/view/transparency"
 #define EOG_CONF_VIEW_TRANS_COLOR		"/apps/eog/view/trans_color"
 
-#define EOG_CONF_WINDOW_GEOMETRY		"/apps/eog/window/geometry_singleton"
-
 #define EOG_CONF_FULLSCREEN_LOOP		"/apps/eog/full_screen/loop"
 #define EOG_CONF_FULLSCREEN_UPSCALE		"/apps/eog/full_screen/upscale"
 #define EOG_CONF_FULLSCREEN_SECONDS		"/apps/eog/full_screen/seconds"
@@ -51,7 +49,9 @@
 #define EOG_CONF_UI_IMAGE_COLLECTION		"/apps/eog/ui/image_collection"
 #define EOG_CONF_UI_IMAGE_COLLECTION_POSITION	"/apps/eog/ui/image_collection_position"
 #define EOG_CONF_UI_IMAGE_COLLECTION_RESIZABLE	"/apps/eog/ui/image_collection_resizable"
+#define EOG_CONF_UI_SIDEBAR			"/apps/eog/ui/sidebar"
 #define EOG_CONF_UI_SCROLL_BUTTONS		"/apps/eog/ui/scroll_buttons"
+#define EOG_CONF_UI_DISABLE_TRASH_CONFIRMATION	"/apps/eog/ui/disable_trash_confirmation"
 
 #define EOG_CONF_PLUGINS_ACTIVE_PLUGINS         "/apps/eog/plugins/active_plugins"
 
